% Evaluating Factor Pricing Models Using High Frequency Panels
% by Yoosoon Chang, Yongok Choi, Hagen Kim, Joon Park
%
% Estimating the Demeaned Excess Market Return
% 
% 2014-03-05  
% Version 2.0 
% By Yongok Choi (choiyongok@gmail.com)
%
clear;clc;
addpath('..\SharedPrg');
load FF_Factors_daily.txt;

SY      = 1963; 
SM      = 7;

EY      = 2008;
EM      = 12;

S_id    = (SY-1963)*12+SM;
E_id    = (EY-1963)*12+EM;

Date    = FF_Factors_daily(:,1); 
Year    = floor(Date/10000);            % Year
Month   = floor(Date/100)-Year*100;     % Month
Mindex  = (Year-1963)*12+Month;

% Select data for the sample period from 1963.7.1 ~ 2008. 12.31
VP_1    = Mindex >=S_id;
VP_2    = Mindex <=E_id;
VP      = VP_1 & VP_2;

ExMkt   = FF_Factors_daily(VP,2);       % Excess Market Return from 1963.7.1 ~ 2008. 12.31

nm      = E_id-S_id+1;                  % # of months in sample
ns      = size(ExMkt,1);                % # of days in sample
Time    = ((1:1:ns))';
h       = (ns/nm)/2;                    % set the bandwidth to be the half month
g       = LL_reg(ExMkt,Time,h,Time);
Dm_Mkt  = ExMkt -g(:,1);                % Demeaned Excess Market Return
Dm_Mkt  = Dm_Mkt(2:end,1);              % Data are from 1963.7.2 ~ 2008. 12.31
save('Dm_Mkt.txt', 'Dm_Mkt', '-ASCII')