clc;clear;
tic;

N_sim       = 10000;  

delta       = 1/252;
subdelta    = 1/1;
nsiy        = 1/delta*1/subdelta;
nsim        = 1/subdelta*21;
nsid        = 1/subdelta; 

seed        = 4956000;
stream      = RandStream('mt19937ar', 'Seed', seed);
RandStream.setGlobalStream(stream);
v           = 0.1;

v_id        = 1;
if v == 0.5;
    v_id = 2;
elseif v== 1;
    v_id = 3;
end

load('pct95_T20_panel_FFT.mat');

Power_rst = zeros(4,22);
for T = 20
    Date    = kron((1:1:T)'+1962,ones(nsiy,1))*10000+repmat(kron((1:1:12)',ones(nsim,1)),T,1)*100+repmat(kron((1:1:21)',ones(nsid,1)),T*12,1);
    c_i     = 1;
    for c   = [0 1 3 5]
        alpha_i = 1;
        for alpha = 0:max(1,c):max(10,c*10);
            Sim_rst = zeros(N_sim,3);
            for j=1:1:N_sim;
            ns          = (T/delta)/subdelta;
            v_1         = v;
            v_2         = v;
            dVW         = randn(ns,2)*sqrt(delta*subdelta);
            dZs         = randn(ns,2)*sqrt(delta*subdelta);   
            V_t         = [0;cumsum(dVW(:,1))];
            W_t         = [0;cumsum(dVW(:,2))];
            s_t         = 1+5*abs(V_t+c*W_t);
            dV_t        = dVW(:,1);
            dW_t        = dVW(:,2);

            dX_t        = s_t(1:end-1,1).*dV_t;
            dU_1t       = s_t(1:end-1,1).*(dW_t+v_1*dZs(:,1));
            dU_2t       = s_t(1:end-1,1).*(dW_t+v_2*dZs(:,2));
            dY1_t       = alpha*delta*subdelta+dU_1t;
            dY2_t       = alpha*delta*subdelta+dU_2t;
            
            dY_t        = [dY1_t dY2_t];
            
            Sim_rst(j,1) = FT_CAPM_woJ(dY_t,Date,dX_t);
            Sim_rst(j,2) = TC_CAPM_woJ(dY_t,Date,dX_t);

            end
            toc;
            I_FT    = abs(Sim_rst(:,1)) > Pct_95((c_i-1)*3+v_id,4) ;
            I_RT1d  = abs(Sim_rst(:,2)) > Pct_95((c_i-1)*3+v_id,6) ;          
            Power_rst(c_i,(alpha_i-1)*2+1) = mean(I_FT);
            Power_rst(c_i,(alpha_i-1)*2+2) = mean(I_RT1d);
        alpha_i = alpha_i + 1;            
        end
    c_i = c_i +1;        
    end
end

%% Result Report

savehead = 'Power_T';
savefilename = [ num2str(T), ...
                '_,v_i=', num2str(v)];
saveformat1 = '.mat';
save([savehead,savefilename,saveformat1],'Power_rst');            

%% Result Graphs
v   = 0.1;
Tic = (0:0.5:5)';
vec_c = [0;1;3;5];

for i=1:1:4;
    c   = vec_c(i,1);
    Tic =  (0:max(1,c):max(10,c*10))';
    TP_OLS = Power_rst(i,1:2:end)';
    TP_TC_1d = Power_rst(i,2:2:end)';
    
    % Create figure
    figure1 = figure;
    set(figure1, 'Units', 'inches');
    set(figure1, 'Position', [1 2 2.9*3 1.4*3]);
    set(figure1, 'PaperPositionMode', 'manual');
    set(figure1, 'PaperUnits', 'inches');
    set(figure1, 'PaperPosition', [1 1 2.9*3 1.4*3]);    

    % Create axes
    axes1 = axes('Parent',figure1,'FontSize',20,'FontName','Tahoma','LineWidth',2);
    box(axes1,'on');
    hold(axes1,'all');
%     xlim(axes1,[0 50]);  
    % Create multiple lines using matrix input to plot
    plot1 = plot(Tic,[TP_OLS TP_TC_1d],'Parent',axes1,'LineWidth',2);
    set(plot1(1),'LineStyle','--','DisplayName','FT');
    set(plot1(2),'DisplayName','RT');
    savetitle = ['c=',num2str(vec_c(i,1))];
    % Create title
    title(savetitle,'FontSize',24,'FontName','Tahoma');
    % Create legend
    legend1 = legend(axes1,'show');
    set(legend1,'EdgeColor',[1 1 1],'Location','SouthEast',...
    'Visible','on');

    savehead = ['Panel_Power_T20_','v_',num2str(v)];
    saveformat1 = '.eps';
    print(figure1,'-depsc',[savehead,savetitle,saveformat1]);   
end

%% results at alpha=10
TR = [Power_rst(1,21:22);Power_rst(2,21:22);Power_rst(3,7:8);Power_rst(3,9:10);Power_rst(4,5:6)]
