function [TCD,Tms,DeltaV] = TimeChange(MDS,Delta,Setting)

%Name:      TimeChange(Time Change)
%Purpose:   Time Change Procedure
%Format:    [TCD,Tms,DeltaV] = TimeChange(MDS,Delta,Setting)
%
%2009-07-18             By Yongok Choi
%Version 1.1 
switch Setting
    case 1      % global & definition
        TQV     = sum(MDS.^2);          %Total Quadratic Variation
        NTCS    = floor(TQV/Delta);     %the Number of the Time Changed Samples
        TimeIdx = cumsum(MDS.^2)/Delta;

        Tms     = zeros(NTCS,1);        %Tms
        DeltaV  = zeros(NTCS,1);        %estimates of realized variance for each period

        for i=1:1:NTCS;
            S_I         = TimeIdx > i;
            Tms(i,1)    = min(length(MDS)-sum(S_I)+1,length(MDS));   
            if i==1 
                DeltaV(i) = sum(MDS(1:Tms(1)).^2);             
            else
                DeltaV(i) = sum(MDS(Tms(i-1)+1:Tms(i)).^2);
            end          
        end
        
        TCD     = MDS(Tms);
        
    case 2      % global & minimum distance
        TQV     = sum(MDS.^2);          %Total Quadratic Variation
        NTCS    = floor(TQV/Delta);     %the Number of the Time Changed Samples
        TimeIdx = cumsum(MDS.^2)/Delta;

        Tms     = zeros(NTCS,1);        %Tms
        DeltaV  = zeros(NTCS,1);        %estimates of realized variance for each period

        for i=1:1:NTCS;
            S_I         = TimeIdx > i;
            S_I_lead    = [S_I(2:end);true];
            if min(abs(TimeIdx(S_I)-i)) <= min(abs(TimeIdx(S_I_lead)-i))
                Tms(i,1) = length(MDS)-sum(S_I)+1;   
            else
                Tms(i,1) = length(MDS)-sum(S_I_lead)+1;                   
            end
            if i==1 
                DeltaV(i) = sum(MDS(1:Tms(1)).^2);
            else
                DeltaV(i) = sum(MDS(Tms(i-1)+1:Tms(i)).^2);
            end          
        end
        
        TCD     = MDS(Tms);       

    case 3      % sequential & minimum distance

        Tmp_MDS = MDS;
        i       = 1;
        Tms     = zeros(0,1);
        DeltaV  = zeros(1,1);
        while sum(Tmp_MDS.^2) > Delta
            Tmp_Tindex      = cumsum(Tmp_MDS.^2);
            S_I             = Tmp_Tindex > Delta;
            S_I_lead        = [S_I(2:end);true];
            if min(abs(Tmp_Tindex(S_I)-Delta)) <= min(abs(Tmp_Tindex(S_I_lead)-Delta))
                Tms         = [Tms;length(MDS)-sum(S_I)+1];
                Tmp_MDS     = Tmp_MDS([false;S_I(1:end-1)]);                
            else
                Tms         = [Tms;length(MDS)-sum(S_I_lead)+1];   
                Tmp_MDS     = Tmp_MDS([false;S_I_lead(1:end-1)]);                                
            end
            if i==1 
                DeltaV(1) = sum(MDS(1:Tms(1)).^2);
            else
                DeltaV = [DeltaV;sum(MDS(Tms(i-1)+1:Tms(i)).^2)];
            end
            i = i+1;
        end
        
         TCD     = MDS(Tms);  
         
                  
    case 4   % sequential & definition 
        Tmp_MDS        = MDS;
        i              = 1;
        Tms            = zeros(0,1);
        DeltaV         = zeros(1,1);
        
        while sum(Tmp_MDS.^2) > Delta
            Tmp_Tindex      = cumsum(Tmp_MDS.^2);
            S_I             = Tmp_Tindex > Delta;
            Tms             = [Tms;length(MDS)-sum(S_I)+1];
            Tmp_MDS         = Tmp_MDS([false;S_I(1:end-1)]);   
           
            if i==1 
                DeltaV(1)  = sum(MDS(1:Tms(1)).^2);
            else
                DeltaV     = [DeltaV;sum(MDS(Tms(i-1)+1:Tms(i)).^2)];
            end
            i = i+1;
        end
   
      TCD     = MDS(Tms);     
end

return;
