function Wald = TC_CAPM_woJ(hprx_vw,Date,Mkt)

% Evaluating Factor Pricing Models Using High Frequency Panels
% by Yoosoon Chang, Yongok Choi, Hagen Kim, Joon Park
% CAPM
% Loading data sets
% 1963.7.1 ~ 2008. 12.31 for the 11 portfolio
% 1963.7.1 ~ 2009. 3.31 for the F-F factor

% Define variables
% Size based 10 portfolios											
% VW Returns	
% Note that 11th regression is redundant, so we run 10 regressions

% R_vw    = Ten_portfolios_on_Size_Daily(:,2:end-1); %Value-weighted returns
% [m,n]   = size(R_vw); % m: # of rows, n: # of columns
% 
% % FF factors and risk-free rate
% Mkt  = FF_Factors_daily(1:m,2);     %Market minus risk free rate
% Rf   = FF_Factors_daily(1:m,end);   %Risk free rate
% 
% % Excess 1-peiod holding period returns and factors in percentage terms
% hprx_vw = R_vw(2:end,:)-kron(Rf(1:end-1,:),ones(1,n));
% Mkt     = Mkt(2:end,:);
% Dm_Mkt  = Mkt-mean(Mkt);
% % 
% % Date    = Ten_portfolios_on_Size_Daily(2:end,1);    %Date


[m,n]   = size(hprx_vw); % m: # of rows, n: # of columns
Dm_Mkt  = Mkt-mean(Mkt);

Year    = floor(Date/10000);                %Year
Month   = floor(Date/100)-Year*100;         %Month
Mindex  = (Year-1963)*12+Month;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Step0: Set the decade that we want to investigate
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

SY      = Year(1,1);
SM      = Month(1,1);
EY      = Year(end,1);
EM      = Month(end,1);

DI_1    = Mindex >= (SY-1963)*12+SM;
DI_2    = Mindex <= (EY-1963)*12+EM;
DI      = DI_1 & DI_2;

hprx_vw     = hprx_vw(DI,:);
Mkt         = Mkt(DI,:);
Dm_Mkt      = Dm_Mkt(DI,:);

Date        = Date(DI,:);
Year        = Year(DI,:);
Month       = Month(DI,:); 
Mindex      = Mindex(DI,:);

MSE_p       = 0.05;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Step1: Fix at monthly average QV of excess mkt return for time change
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

QV      = cumsum(Dm_Mkt.^2,1);                     %Quadratic Variation
TQV     = sum(Dm_Mkt.^2,1);                        %Total Quadratic Variation
MDelta  = TQV/(max(Mindex)-min(Mindex)+1);      %Monthly Equivalent Delta
% 
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% % Step2: Jump Test by Lee and Mykland
% %       - get the date and month information
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% K       = 16;                               %window size
% alpha   = 0.05;                             %significance level
% 
% rejidx   = JT_LM(Dm_Mkt,K,alpha);              %reject index(jump indicate)
% % Jumpdate = Date(rejidx);                  %Date for Jumps

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Step3: Select valid time changed sample
%       - remove samples whose period includes Jumps
%       - remove samples whose contribution to MSE is high
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[TCD,Tms,DeltaV] = TimeChange(Dm_Mkt,MDelta,3);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Constructing Time Change Interval Information
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Sdate   = [Date(1);Date(Tms(1:end-1)+1)];
Edate   = Date(Tms(1:end));
Nobs    = [Tms(1);Tms(2:end)-Tms(1:end-1)];

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% % treat Jumps
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Jump    = zeros(length(Tms),1);
% for i = 1:1:length(Tms)
%     if i == 1
%         Jump(i) = any(rejidx(1:Tms(1)));
%     else
%         Jump(i) = any(rejidx(Tms(i-1)+1:Tms(i)));
%     end
% end
% 
% VP_Jump = Jump < 1; % Valid Periods without Jumps
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% treat MSE
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
% S_SE    = sort((DeltaV-MDelta).^2,1,'descend');%Sorted Square Error
% MSE_plot= zeros(length(Tms),1);
% 
% for i=1:1:length(Tms)
%    MSE_plot(i,1) = mean(S_SE(i:end),1); 
% end
% Xaxis = (100:-1:0)';
% Yaxis = prctile(MSE_plot,Xaxis);
% 
% bar (Xaxis,Yaxis);
% set(gca,'XDir','reverse');
% set(gca,'XLim',[50 100]);
% title ('MSE along the percentile','FontName','Verdana','FontSize',16);
% xlabel ('Percentile');
% ylabel ('MSE','Rotation',0.0);
% figure(gcf)

% VP_MSE  = (DeltaV-MDelta).^2 < S_SE(round(length(Tms)*MSE_p));   %Valid Periods in terms of MSE 
% VP      = VP_MSE;
% VP      = VP_MSE & VP_Jump;

% fprintf('Data period: from %6.0f - %2.0f to %6.0f - %2.0f',SY,SM,EY,EM);
% fprintf('\n The number of months is                             %10.4f. ', max(Mindex)-min(Mindex)+1);
% fprintf('\n The number of the time changed samples is           %10.4f', length(Nobs));
% fprintf('\n The number of samples with Jumps is                 %10.4f. ', sum(Jump));
% fprintf('\n The number of samples violating MSE criterion is    %10.4f. ', round(length(Tms)*MSE_p));
% fprintf('\n The number of used samples is                       %10.4f. ', sum(VP));

% VP      = true(NM,1);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Step4: Build Monthly Data 
%       - remove months which jumps happened
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

NM      = length(Nobs);
MY      = zeros(NM,n);
MX      = zeros(NM,2);

for i=1:1:NM;
    S_I_1   = Date >= Sdate(i,1);
    S_I_2   = Date <= Edate(i,1);
    S_I     = S_I_1 & S_I_2;
    Temp_Y  = hprx_vw(S_I,:);
    Temp_X  = Mkt(S_I,:);
    MX(i,:) = [sum(S_I,1)/252*100 sum(Temp_X,1)];
    MY(i,:) = sum(Temp_Y,1);
end

% MX  = MX(VP,:);
% MY  = MY(VP,:);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Step5: For each i=1, ... , 10, estimate betas by running OLS over Monthly
% data
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

BigBhat = inv(MX'*MX)*MX'*MY;
BigBhatT = BigBhat';
BetaRst_1=[ BigBhatT(:,1);0;0;mean(BigBhatT(:,1));std(BigBhatT(:,1)) ];
BetaRst_2=[ BigBhatT(:,2);0;0;mean(BigBhatT(:,2));std(BigBhatT(:,2)) ];
BetaRst = [BetaRst_1 BetaRst_2];
Uhat    = MY - MX*BigBhat;

[nr,nc]     = size(MX);
s2          = sum(Uhat.^2,1)/(nr-nc);
Bigse       = sqrt(diag(inv(MX'*MX))*s2);
BigseT      = Bigse';

BigEstRst   = zeros(n,nc*2);
for i=1:1:nc;
    BigEstRst(:,2*(i-1)+1) = BigBhatT(:,i);
    BigEstRst(:,2*(i-1)+2) = BigseT(:,i);
end

% STs2    = sum(sum(cov(MY(:,1),MY(:,10)).*(2*eye(2)-ones(2,2))));
% STse    = sqrt(diag(inv(MX'*MX))*STs2);
% fprintf('\n standard errors of the strategy is %10.4f',STse);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Step6: construct fitted residuals at daily frequncy using beta hat 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

BigUhat = hprx_vw - [ones(length(Mkt),1)/252*100 Mkt]*BigBhat;

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% % Step7: Plot alpha_i vs index 
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% figure1 = figure('PaperSize',[20.98 29.68]);    % Create figure
% 
% axes('Parent',figure1);                         % Create axes
% box('on');hold('all');
% plot(BigBhat(1,:),'-o');                             % Create plot
% title('\alpha_i along with index','FontSize',16,'FontName','Verdana');  
%                                                 % Create title
% gridxy([],0,'Linestyle',':','linewidth',2) ;                                                                                           
%                                             
% xlabel('index');                                % Create xlabel
% ylabel('\alpha_i');                             % Create ylabel

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Step8: Estimate error variance matrix
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

MU      = zeros(NM,n);
Omegahats = zeros(n,n,NM);

for i=1:1:NM;
    S_I_1   = Date >= Sdate(i,1);
    S_I_2   = Date <= Edate(i,1);
    S_I     = S_I_1 & S_I_2;
    Temp_U  = BigUhat(S_I,:);
    Temp_Omega = zeros(n,n);
    [nrow,ncol] = size(Temp_U);
    for j=1:1:nrow;
        Temp_Omega = Temp_Omega + Temp_U(j,:)'*Temp_U(j,:);
    end;
    Omegahats(:,:,i) = Temp_Omega;
end
%Sigmahat2 = Omegahats(:,:,VP);
Sigmahat = mean(Omegahats,3);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Step9: Calcuate Wald statistic
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

X1 = MX(:,1);
X2 = MX(:,2);

star = inv(X1'*X1-X1'*X2*inv(X2'*X2)*X2'*X1);
Wald = inv(star)*BigBhat(1,:)*inv(Sigmahat)*BigBhat(1,:)';


