% Evaluating Factor Pricing Models Using High Frequency Panels
% by Yoosoon Chang, Yongok Choi, Hagen Kim, Joon Park
%
% Summary Statistics of Portfolio Returns
% Input: 1. FF_Factors_daily.txt
%           1963.7.1 ~ 2009. 3.31 for the risk free rate
%        2. Ten_portfolios_on_Size_Daily.txt
%           1963.7.1 ~ 2008. 12.31 for the 11 portfolios(Size)
%        3. 11_portfolios_BE_ME.txt
%           1963.7.1 ~ 2008. 12.31 for the 11 portfolios(B/M)
% Output: Panel_B 
%
% 2014-01-31  
% Version 2.0 
% By Yongok Choi (choiyongok@gmail.com)

clear all; close all; clc;

% Loading data sets
% 1963.7.1 ~ 2009. 3.31 for the F-F factor
% 1963.7.1 ~ 2008. 12.31 for the 11 portfolios(Size)
load ('..\..\Data\FF_Factors_daily.txt'); % Fama-French factors and risk-free rate
load ('..\..\Data\Ten_portfolios_on_Size_Daily.txt'); %Value-weighted returns

% Size Portfolios (Decile plus Lo-Hi)	
% Value-weighted returns (daily, percentage)
R_vw    = Ten_portfolios_on_Size_Daily(:,2:end);
[n,m]   = size(R_vw); % n: # of rows, m: # of columns

% Risk-free rate
Rf      = FF_Factors_daily(1:n,end);   

% Excess 1-peiod holding period returns and factors in percentage terms
hprx_vw = [R_vw(2:end,1:10)-kron(Rf(1:end-1,:),ones(1,m-1)) R_vw(2:end,11)];

R_vw       = hprx_vw;
Mean_S     = mean(R_vw,1)'*252/100;
Std_S      = std(R_vw,1)'*sqrt(252)/100;
Rst_S      = [Mean_S Std_S];

% Loading data set
% 1963.7.1 ~ 2008. 12.31 for the 11 portfolio(BM)
load ('..\..\Data\11_portfolios_BE_ME.txt'); %Value-weighted returns

% Value Weigted Returns (daily, percentage)											
% 10 portfolios based on BE_ME ratio plus the Hi-Lo portfolio (11th)

R_vw        = X11_portfolios_BE_ME(:,2:end); %Value-weighted returns

% Excess 1-peiod holding period returns and factors in percentage terms
hprx_vw     = [R_vw(2:end,1:10)-kron(Rf(1:end-1,:),ones(1,m-1)) R_vw(2:end,11)];

R_vw        = hprx_vw;
Mean_BM     = mean(R_vw,1)'*252/100;
Std_BM      = std(R_vw,1)'*sqrt(252)/100;
Rst_BM      = [Mean_BM Std_BM];

Panel_B     = [Rst_S Rst_BM];



